@@ -852,7 +852,6 @@ gsr_discard_confirmation_dialog (GSRWindow *window, gboolean closing)
 	GtkWidget *confirmation_dialog;
 	AtkObject *atk_obj;
 	gint response_id;
-	gchar *utf8_filename = NULL;
 	gboolean ret = TRUE;
 
 	confirmation_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (window),
@@ -1000,7 +999,7 @@ fill_in_information (GSRWindow *window,
 		file_size = (guint64) buf.st_size;
 		human = g_format_size_for_display (file_size);
 
-		text = g_strdup_printf (ngettext ("%s (%llu byte)", "%s (%llu bytes)", 
+		text = g_strdup_printf (ngettext ("%s (%llu byte)", "%s (%llu bytes)",
 		                        file_size), human, file_size);
 		g_free (human);
 	} else {
@@ -1088,7 +1087,9 @@ file_properties_cb (GtkAction *action,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
 	g_free (title);
+#if !GTK_CHECK_VERSION (2, 21, 8)
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+#endif
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
