@@ -47,7 +47,8 @@ typedef struct _GnomeVolumeControlTrack {
 	    *sliderbox,
 	    *buttonbox,
 	    *toggle,
-	    *options;
+	    *options,
+	    *flagbuttonbox;
 
   GnomeVolumeControlButton *mute, *record;
 
@@ -72,7 +73,7 @@ GnomeVolumeControlTrack *
 						 GstMixerTrack *track,
 						 GtkWidget *l_sep,
 						 GtkWidget *r_sep,
-						 GtkStatusbar *statusbar);
+						 GtkWidget *fbox);
 GnomeVolumeControlTrack *
 	gnome_volume_control_track_add_recording(GtkTable *table,
 						 gint      tab_pos,
@@ -80,7 +81,7 @@ GnomeVolumeControlTrack *
 						 GstMixerTrack *track,
 						 GtkWidget *l_sep,
 						 GtkWidget *r_sep,
-						 GtkStatusbar *statusbar);
+						 GtkWidget *fbox);
 
 GnomeVolumeControlTrack *
 	gnome_volume_control_track_add_switch	(GtkTable *table,
@@ -89,7 +90,7 @@ GnomeVolumeControlTrack *
 						 GstMixerTrack *track,
 						 GtkWidget *l_sep,
 						 GtkWidget *r_sep,
-						 GtkStatusbar *statusbar);
+						 GtkWidget *fbox);
 
 GnomeVolumeControlTrack *
 	gnome_volume_control_track_add_option	(GtkTable *table,
@@ -98,13 +99,15 @@ GnomeVolumeControlTrack *
 						 GstMixerTrack *track,
 						 GtkWidget *l_sep,
 						 GtkWidget *r_sep,
-						 GtkStatusbar *statusbar);
+						 GtkWidget *fbox);
 
 void	gnome_volume_control_track_free		(GnomeVolumeControlTrack *track);
 
 void	gnome_volume_control_track_show		(GnomeVolumeControlTrack *track,
 						 gboolean  visible);
 
+void    gnome_volume_control_track_update       (GnomeVolumeControlTrack *trkw);
+
 G_END_DECLS
 
 #endif /* __GVC_TRACK_H__ */
